@@ -1,6 +1,4 @@
-if (!require ("stats", quietly=TRUE))
-    stop("package", sQuote("stats"), "is needed.  Stopping")
-camp <- ts(c(
+camp <- stats::ts(c(
  37., 60., 71., 55., 53., 78., 53., 34., 54., 66., 63., 64., 81., 83., 82., 67., 61., 63.,        
  45., 71., 67., 47., 47., 45., 59., 58., 68., 65., 74., 48., 22., 48., 40., 45., 33., 50.,        
  47., 43., 52., 55., 41., 49., 53., 59., 49., 64., 64., 75., 63., 51., 50., 55., 56., 61.,        
@@ -303,4 +301,3 @@ camp <- ts(c(
  52., 59., 69., 70., 51., 67., 61., 62., 56., 59., 51., 59., 32., 31., 55., 57., 69., 60.,        
  53., 55., 64., 68., 60.),
 start = -3435, end = 1969, frequency = 1)
-             
